@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Exception.pm 7061 2007-05-07T03:31:40.439848Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Exception.pm 7191 2007-05-15T02:45:51.609363Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -10,7 +10,11 @@ use Exception::Class
     'Gungho::Exception',
     map {
         ($_ => { isa => 'Gungho::Exception' })
-    } qw(Gungho::Exception::RequestThrottled)
+    } qw(
+        Gungho::Exception::RequestThrottled
+        Gungho::Exception::SendRequest::Handled
+        Gungho::Exception::HandleResponse::Handled
+    )
 ;
 
 1;
